﻿// $Header: $ 
// Copyright (c) CODE Consulting and Development, s.r.o., Plzen. All rights reserved.

// ReSharper disable CommentTypo
// ReSharper disable InconsistentNaming
// ReSharper disable StringLiteralTypo
// ReSharper disable LocalizableElement
// ReSharper disable PossibleNullReferenceException
#region Example
// This example shows how to subscribe to event notifications and display each incoming event.

using System;
using OpcLabs.EasyOpc.UA;
using OpcLabs.EasyOpc.UA.AddressSpace.Standard;
using OpcLabs.EasyOpc.UA.OperationModel;

namespace UADocExamples.AlarmsAndConditions
{
    partial class SubscribeEvent
    {
        public static void Overload1()
        {
            // Define which server we will work with.
            UAEndpointDescriptor endpointDescriptor =
                "opc.tcp://opcua.demo-this.com:62544/Quickstarts/AlarmConditionServer";

            // Instantiate the client object and hook events
            var client = new EasyUAClient();
            client.EventNotification += client_EventNotification;

            Console.WriteLine("Subscribing...");
            client.SubscribeEvent(endpointDescriptor, UAObjectIds.Server, 1000);

            Console.WriteLine("Processing event notifications for 30 seconds...");
            System.Threading.Thread.Sleep(30 * 1000);

            Console.WriteLine("Unsubscribing...");
            client.UnsubscribeAllMonitoredItems();

            Console.WriteLine("Waiting for 5 seconds...");
            System.Threading.Thread.Sleep(5 * 1000);
        }

        static void client_EventNotification(object sender, EasyUAEventNotificationEventArgs e)
        {
            // Display the event
            Console.WriteLine(e);
        }



        // Example output (truncated):
        //Subscribing...
        //Processing event notifications for 30 seconds...
        //[] Success
        //[] Success; Refresh; RefreshInitiated
        //[] Success; Refresh; (10 field results) [EastTank] 100! "The dialog was activated" @9/10/2019 8:08:23 PM
        //[] Success; Refresh; (10 field results) [EastTank] 500! "The alarm was acknoweledged." @10/14/2019 4:00:13 PM
        //[] Success; Refresh; (10 field results) [EastTank] 100! "The alarm was acknoweledged." @11/9/2019 9:56:23 AM
        //[] Success; Refresh; (10 field results) [EastTank] 500! "The alarm was acknoweledged." @10/14/2019 4:00:17 PM
        //[] Success; Refresh; (10 field results) [EastTank] 100! "The alarm severity has increased." @9/10/2019 8:09:07 PM
        //[] Success; Refresh; (10 field results) [EastTank] 100! "The alarm severity has increased." @9/10/2019 8:10:09 PM
        //[] Success; Refresh; (10 field results) [NorthMotor] 100! "The dialog was activated" @9/10/2019 8:08:25 PM
        //[] Success; Refresh; (10 field results) [NorthMotor] 500! "The alarm was acknoweledged." @10/14/2019 4:00:02 PM
        //[] Success; Refresh; (10 field results) [NorthMotor] 500! "The alarm was acknoweledged." @10/14/2019 4:00:16 PM
        //[] Success; Refresh; (10 field results) [NorthMotor] 500! "The alarm severity has increased." @11/9/2019 2:56:37 PM
        //[] Success; Refresh; (10 field results) [NorthMotor] 100! "The alarm severity has increased." @9/10/2019 8:09:11 PM
        //[] Success; Refresh; (10 field results) [NorthMotor] 100! "The alarm severity has increased." @9/10/2019 8:10:19 PM
        //[] Success; Refresh; (10 field results) [WestTank] 100! "The dialog was activated" @9/10/2019 8:08:25 PM
        //[] Success; Refresh; (10 field results) [WestTank] 300! "The alarm was acknoweledged." @10/14/2019 4:00:12 PM
        //[] Success; Refresh; (10 field results) [WestTank] 500! "The alarm severity has increased." @11/9/2019 2:56:37 PM
        //[] Success; Refresh; (10 field results) [WestTank] 300! "The alarm was acknoweledged." @10/14/2019 4:00:04 PM
        //[] Success; Refresh; (10 field results) [WestTank] 100! "The alarm severity has increased." @9/10/2019 8:08:58 PM
        //[] Success; Refresh; (10 field results) [WestTank] 100! "The alarm severity has increased." @9/10/2019 8:09:48 PM
        //[] Success; Refresh; (10 field results) [SouthMotor] 100! "The dialog was activated" @9/10/2019 8:08:25 PM
        //[] Success; Refresh; (10 field results) [SouthMotor] 500! "The alarm severity has increased." @11/9/2019 2:56:37 PM
        //[] Success; Refresh; (10 field results) [SouthMotor] 700! "The alarm was acknoweledged." @10/14/2019 4:00:21 PM
        //[] Success; Refresh; (10 field results) [SouthMotor] 500! "The alarm was acknoweledged." @10/14/2019 4:00:03 PM
        //[] Success; Refresh; (10 field results) [SouthMotor] 100! "The alarm severity has increased." @9/10/2019 8:09:02 PM
        //[] Success; Refresh; (10 field results) [SouthMotor] 100! "The alarm severity has increased." @9/10/2019 8:09:59 PM
        //[] Success; Refresh; RefreshComplete
        //[] Success; (10 field results) [Internal] 500! "Raising Events" @11/9/2019 2:56:41 PM
        //[] Success; (10 field results) [Internal] 500! "Events Raised" @11/9/2019 2:56:41 PM
        //[] Success; (10 field results) [Internal] 500! "Raising Events" @11/9/2019 2:56:42 PM
        //[] Success; (10 field results) [Internal] 500! "Events Raised" @11/9/2019 2:56:42 PM
        //[] Success; (10 field results) [Internal] 500! "Raising Events" @11/9/2019 2:56:43 PM
        //[] Success; (10 field results) [Internal] 500! "Events Raised" @11/9/2019 2:56:43 PM
        //[] Success; (10 field results) [Internal] 500! "Raising Events" @11/9/2019 2:56:44 PM
        //[] Success; (10 field results) [Internal] 500! "Events Raised" @11/9/2019 2:56:44 PM
        //[] Success; (10 field results) [Internal] 500! "Raising Events" @11/9/2019 2:56:45 PM
        //[] Success; (10 field results) [Internal] 500! "Events Raised" @11/9/2019 2:56:45 PM
        //[] Success; (10 field results) [Internal] 500! "Raising Events" @11/9/2019 2:56:46 PM
        //[] Success; (10 field results) [Internal] 500! "Events Raised" @11/9/2019 2:56:46 PM
        //[] Success; (10 field results) [Internal] 500! "Raising Events" @11/9/2019 2:56:47 PM
        //[] Success; (10 field results) [Internal] 500! "Events Raised" @11/9/2019 2:56:47 PM
        //[] Success; (10 field results) [Internal] 500! "Raising Events" @11/9/2019 2:56:48 PM
        //[] Success; (10 field results) [NorthMotor] 700! "The alarm severity has increased." @11/9/2019 2:56:48 PM
        //[] Success; (10 field results) [Internal] 500! "Events Raised" @11/9/2019 2:56:48 PM
        //[] Success; (10 field results) [WestTank] 700! "The alarm severity has increased." @11/9/2019 2:56:48 PM
        //[] Success; (10 field results) [SouthMotor] 700! "The alarm severity has increased." @11/9/2019 2:56:48 PM
        //[] Success; (10 field results) [Internal] 500! "Raising Events" @11/9/2019 2:56:49 PM
        //[] Success; (10 field results) [Internal] 500! "Events Raised" @11/9/2019 2:56:49 PM
        //[] Success; (10 field results) [Internal] 500! "Raising Events" @11/9/2019 2:56:50 PM
        //...
    }
}
#endregion
